aboutsummaryrefslogtreecommitdiff
path: root/src/patch/coords.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/patch/coords.hh')
-rw-r--r--src/patch/coords.hh16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/patch/coords.hh b/src/patch/coords.hh
index f101b1f..c0ae3e8 100644
--- a/src/patch/coords.hh
+++ b/src/patch/coords.hh
@@ -53,10 +53,10 @@
//
//
// We also use direction cosines (alpha,beta,gamma):
// alpha = x/r = cos(angle between vector from origin to (x,y,z), and x axis)
// beta = y/r = cos(angle between vector from origin to (x,y,z), and y axis)
// gamma = z/r = cos(angle between vector from origin to (x,y,z), and z axis)
//
//
@@ -177,10 +177,10 @@ void mu_nu_of_theta_phi(fp ps_theta, fp ps_phi, fp& mu, fp& nu );
void mu_phi_of_theta_phi(fp ps_theta, fp ps_phi, fp& mu, fp& phi);
void nu_phi_of_theta_phi(fp ps_theta, fp ps_phi, fp& nu, fp& phi);
-// ((mu,nu,phi)) --> direction cosines (alpha,beta,gamma)
-void alpha_beta_gamma_of_mu_nu (fp mu, fp nu , fp& alpha, fp& beta, fp& gamma);
-void alpha_beta_gamma_of_mu_phi(fp mu, fp phi, fp& alpha, fp& beta, fp& gamma);
-void alpha_beta_gamma_of_nu_phi(fp nu, fp phi, fp& alpha, fp& beta, fp& gamma);
+// ((mu,nu,phi)) --> direction cosines (xcos,ycos,zcos)
+void xyzcos_of_mu_nu (fp mu, fp nu , fp& xcos, fp& ycos, fp& zcos);
+void xyzcos_of_mu_phi(fp mu, fp phi, fp& xcos, fp& ycos, fp& zcos);
+void xyzcos_of_nu_phi(fp nu, fp phi, fp& xcos, fp& ycos, fp& zcos);
}; // close namespace local_coords::
//*****************************************************************************
@@ -53,10 +53,10 @@
//
//
-// We also use direction cosines (alpha,beta,gamma):
-// alpha = x/r = cos(angle between vector from origin to (x,y,z), and x axis)
-// beta = y/r = cos(angle between vector from origin to (x,y,z), and y axis)
-// gamma = z/r = cos(angle between vector from origin to (x,y,z), and z axis)
+// We also use direction cosines (xcos,ycos,zcos):
+// xcos = x/r = cos(angle between vector from origin to (x,y,z), and x axis)
+// ycos = y/r = cos(angle between vector from origin to (x,y,z), and y axis)
+// zcos = z/r = cos(angle between vector from origin to (x,y,z), and z axis)
//
//